summary refs log tree commit diff
path: root/pkgs/development/python-modules
diff options
context:
space:
mode:
authorThomas Tuegel <ttuegel@gmail.com>2015-06-04 17:17:40 -0500
committerThomas Tuegel <ttuegel@gmail.com>2015-06-04 17:44:31 -0500
commitbfe106cfa6613c4ab5c6b7aa6a0650e11bc63267 (patch)
tree145b06e8089427ab32548dc312662d0e279245f5 /pkgs/development/python-modules
parente729a88474da9e6cccd111a5f7c71f164ab8d784 (diff)
downloadnixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar.gz
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar.bz2
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar.lz
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar.xz
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.tar.zst
nixpkgs-bfe106cfa6613c4ab5c6b7aa6a0650e11bc63267.zip
Build numpy and scipy with openblas
Fixes #6772.
Diffstat (limited to 'pkgs/development/python-modules')
-rw-r--r--pkgs/development/python-modules/numpy-scipy-support.nix14
1 files changed, 7 insertions, 7 deletions
diff --git a/pkgs/development/python-modules/numpy-scipy-support.nix b/pkgs/development/python-modules/numpy-scipy-support.nix
index 22be22633c2..915b27cb4cd 100644
--- a/pkgs/development/python-modules/numpy-scipy-support.nix
+++ b/pkgs/development/python-modules/numpy-scipy-support.nix
@@ -3,14 +3,14 @@
   python,
   # Name of package (e.g. numpy or scipy)
   pkgName,
-  # Atlas math library
-  atlas
+  # OpenBLAS math library
+  openblas
 }:
 
 {
   # Re-export atlas here so that it can be sure that the same one will be used
   # in the propagatedBuildInputs.
-  inherit atlas;
+  inherit openblas;
 
   # First "install" the package, then import what was installed, and call the
   # .test() function, which will run the test suite.
@@ -48,9 +48,9 @@
   preBuild = ''
     echo "Creating site.cfg file..."
     cat << EOF > site.cfg
-    [atlas]
-    include_dirs = ${atlas}/include
-    library_dirs = ${atlas}/lib
+    [openblas]
+    include_dirs = ${openblas}/include
+    library_dirs = ${openblas}/lib
     EOF
   '';
 }
@@ -3,14 +3,14 @@
 
 {
-  # Re-export atlas here so that it can be sure that the same one will be used
+  # Re-export openblas here so that it can be sure that the same one will be used
   # in the propagatedBuildInputs.